/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_en extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "JPY", "\u00a5" },
            { "USD", "$" },
            { "adp", "Andorran Peseta" },
            { "aed", "United Arab Emirates Dirham" },
            { "afa", "Afghan Afghani (1927\u20132002)" },
            { "afn", "Afghan Afghani" },
            { "alk", "Albanian Lek (1946\u20131965)" },
            { "all", "Albanian Lek" },
            { "amd", "Armenian Dram" },
            { "ang", "Netherlands Antillean Guilder" },
            { "aoa", "Angolan Kwanza" },
            { "aok", "Angolan Kwanza (1977\u20131991)" },
            { "aon", "Angolan New Kwanza (1990\u20132000)" },
            { "aor", "Angolan Readjusted Kwanza (1995\u20131999)" },
            { "ara", "Argentine Austral" },
            { "arl", "Argentine Peso Ley (1970\u20131983)" },
            { "arm", "Argentine Peso (1881\u20131970)" },
            { "arp", "Argentine Peso (1983\u20131985)" },
            { "ars", "Argentine Peso" },
            { "ats", "Austrian Schilling" },
            { "aud", "Australian Dollar" },
            { "awg", "Aruban Florin" },
            { "azm", "Azerbaijani Manat (1993\u20132006)" },
            { "azn", "Azerbaijani Manat" },
            { "bad", "Bosnia-Herzegovina Dinar (1992\u20131994)" },
            { "bam", "Bosnia-Herzegovina Convertible Mark" },
            { "ban", "Bosnia-Herzegovina New Dinar (1994\u20131997)" },
            { "bbd", "Barbadian Dollar" },
            { "bdt", "Bangladeshi Taka" },
            { "bec", "Belgian Franc (convertible)" },
            { "bef", "Belgian Franc" },
            { "bel", "Belgian Franc (financial)" },
            { "bgl", "Bulgarian Hard Lev" },
            { "bgm", "Bulgarian Socialist Lev" },
            { "bgn", "Bulgarian Lev" },
            { "bgo", "Bulgarian Lev (1879\u20131952)" },
            { "bhd", "Bahraini Dinar" },
            { "bif", "Burundian Franc" },
            { "bmd", "Bermudan Dollar" },
            { "bnd", "Brunei Dollar" },
            { "bob", "Bolivian Boliviano" },
            { "bol", "Bolivian Boliviano (1863\u20131963)" },
            { "bop", "Bolivian Peso" },
            { "bov", "Bolivian Mvdol" },
            { "brb", "Brazilian New Cruzeiro (1967\u20131986)" },
            { "brc", "Brazilian Cruzado (1986\u20131989)" },
            { "bre", "Brazilian Cruzeiro (1990\u20131993)" },
            { "brl", "Brazilian Real" },
            { "brn", "Brazilian New Cruzado (1989\u20131990)" },
            { "brr", "Brazilian Cruzeiro (1993\u20131994)" },
            { "brz", "Brazilian Cruzeiro (1942\u20131967)" },
            { "bsd", "Bahamian Dollar" },
            { "btn", "Bhutanese Ngultrum" },
            { "buk", "Burmese Kyat" },
            { "bwp", "Botswanan Pula" },
            { "byb", "Belarusian Ruble (1994\u20131999)" },
            { "byn", "Belarusian Ruble" },
            { "byr", "Belarusian Ruble (2000\u20132016)" },
            { "bzd", "Belize Dollar" },
            { "cad", "Canadian Dollar" },
            { "cdf", "Congolese Franc" },
            { "che", "WIR Euro" },
            { "chf", "Swiss Franc" },
            { "chw", "WIR Franc" },
            { "cle", "Chilean Escudo" },
            { "clf", "Chilean Unit of Account (UF)" },
            { "clp", "Chilean Peso" },
            { "cnh", "Chinese Yuan (offshore)" },
            { "cnx", "Chinese People\u2019s Bank Dollar" },
            { "cny", "Chinese Yuan" },
            { "cop", "Colombian Peso" },
            { "cou", "Colombian Real Value Unit" },
            { "crc", "Costa Rican Col\u00f3n" },
            { "csd", "Serbian Dinar (2002\u20132006)" },
            { "csk", "Czechoslovak Hard Koruna" },
            { "cuc", "Cuban Convertible Peso" },
            { "cup", "Cuban Peso" },
            { "cve", "Cape Verdean Escudo" },
            { "cyp", "Cypriot Pound" },
            { "czk", "Czech Koruna" },
            { "ddm", "East German Mark" },
            { "dem", "German Mark" },
            { "djf", "Djiboutian Franc" },
            { "dkk", "Danish Krone" },
            { "dop", "Dominican Peso" },
            { "dzd", "Algerian Dinar" },
            { "ecs", "Ecuadorian Sucre" },
            { "ecv", "Ecuadorian Unit of Constant Value" },
            { "eek", "Estonian Kroon" },
            { "egp", "Egyptian Pound" },
            { "ern", "Eritrean Nakfa" },
            { "esa", "Spanish Peseta (A account)" },
            { "esb", "Spanish Peseta (convertible account)" },
            { "esp", "Spanish Peseta" },
            { "etb", "Ethiopian Birr" },
            { "eur", "Euro" },
            { "fim", "Finnish Markka" },
            { "fjd", "Fijian Dollar" },
            { "fkp", "Falkland Islands Pound" },
            { "frf", "French Franc" },
            { "gbp", "British Pound" },
            { "gek", "Georgian Kupon Larit" },
            { "gel", "Georgian Lari" },
            { "ghc", "Ghanaian Cedi (1979\u20132007)" },
            { "ghs", "Ghanaian Cedi" },
            { "gip", "Gibraltar Pound" },
            { "gmd", "Gambian Dalasi" },
            { "gnf", "Guinean Franc" },
            { "gns", "Guinean Syli" },
            { "gqe", "Equatorial Guinean Ekwele" },
            { "grd", "Greek Drachma" },
            { "gtq", "Guatemalan Quetzal" },
            { "gwe", "Portuguese Guinea Escudo" },
            { "gwp", "Guinea-Bissau Peso" },
            { "gyd", "Guyanaese Dollar" },
            { "hkd", "Hong Kong Dollar" },
            { "hnl", "Honduran Lempira" },
            { "hrd", "Croatian Dinar" },
            { "hrk", "Croatian Kuna" },
            { "htg", "Haitian Gourde" },
            { "huf", "Hungarian Forint" },
            { "idr", "Indonesian Rupiah" },
            { "iep", "Irish Pound" },
            { "ilp", "Israeli Pound" },
            { "ilr", "Israeli Shekel (1980\u20131985)" },
            { "ils", "Israeli New Shekel" },
            { "inr", "Indian Rupee" },
            { "iqd", "Iraqi Dinar" },
            { "irr", "Iranian Rial" },
            { "isj", "Icelandic Kr\u00f3na (1918\u20131981)" },
            { "isk", "Icelandic Kr\u00f3na" },
            { "itl", "Italian Lira" },
            { "jmd", "Jamaican Dollar" },
            { "jod", "Jordanian Dinar" },
            { "jpy", "Japanese Yen" },
            { "kes", "Kenyan Shilling" },
            { "kgs", "Kyrgystani Som" },
            { "khr", "Cambodian Riel" },
            { "kmf", "Comorian Franc" },
            { "kpw", "North Korean Won" },
            { "krh", "South Korean Hwan (1953\u20131962)" },
            { "kro", "South Korean Won (1945\u20131953)" },
            { "krw", "South Korean Won" },
            { "kwd", "Kuwaiti Dinar" },
            { "kyd", "Cayman Islands Dollar" },
            { "kzt", "Kazakhstani Tenge" },
            { "lak", "Laotian Kip" },
            { "lbp", "Lebanese Pound" },
            { "lkr", "Sri Lankan Rupee" },
            { "lrd", "Liberian Dollar" },
            { "lsl", "Lesotho Loti" },
            { "ltl", "Lithuanian Litas" },
            { "ltt", "Lithuanian Talonas" },
            { "luc", "Luxembourgian Convertible Franc" },
            { "luf", "Luxembourgian Franc" },
            { "lul", "Luxembourg Financial Franc" },
            { "lvl", "Latvian Lats" },
            { "lvr", "Latvian Ruble" },
            { "lyd", "Libyan Dinar" },
            { "mad", "Moroccan Dirham" },
            { "maf", "Moroccan Franc" },
            { "mcf", "Monegasque Franc" },
            { "mdc", "Moldovan Cupon" },
            { "mdl", "Moldovan Leu" },
            { "mga", "Malagasy Ariary" },
            { "mgf", "Malagasy Franc" },
            { "mkd", "Macedonian Denar" },
            { "mkn", "Macedonian Denar (1992\u20131993)" },
            { "mlf", "Malian Franc" },
            { "mmk", "Myanmar Kyat" },
            { "mnt", "Mongolian Tugrik" },
            { "mop", "Macanese Pataca" },
            { "mro", "Mauritanian Ouguiya (1973\u20132017)" },
            { "mru", "Mauritanian Ouguiya" },
            { "mtl", "Maltese Lira" },
            { "mtp", "Maltese Pound" },
            { "mur", "Mauritian Rupee" },
            { "mvp", "Maldivian Rupee (1947\u20131981)" },
            { "mvr", "Maldivian Rufiyaa" },
            { "mwk", "Malawian Kwacha" },
            { "mxn", "Mexican Peso" },
            { "mxp", "Mexican Silver Peso (1861\u20131992)" },
            { "mxv", "Mexican Investment Unit" },
            { "myr", "Malaysian Ringgit" },
            { "mze", "Mozambican Escudo" },
            { "mzm", "Mozambican Metical (1980\u20132006)" },
            { "mzn", "Mozambican Metical" },
            { "nad", "Namibian Dollar" },
            { "ngn", "Nigerian Naira" },
            { "nic", "Nicaraguan C\u00f3rdoba (1988\u20131991)" },
            { "nio", "Nicaraguan C\u00f3rdoba" },
            { "nlg", "Dutch Guilder" },
            { "nok", "Norwegian Krone" },
            { "npr", "Nepalese Rupee" },
            { "nzd", "New Zealand Dollar" },
            { "omr", "Omani Rial" },
            { "pab", "Panamanian Balboa" },
            { "pei", "Peruvian Inti" },
            { "pen", "Peruvian Sol" },
            { "pes", "Peruvian Sol (1863\u20131965)" },
            { "pgk", "Papua New Guinean Kina" },
            { "php", "Philippine Peso" },
            { "pkr", "Pakistani Rupee" },
            { "pln", "Polish Zloty" },
            { "plz", "Polish Zloty (1950\u20131995)" },
            { "pte", "Portuguese Escudo" },
            { "pyg", "Paraguayan Guarani" },
            { "qar", "Qatari Rial" },
            { "rhd", "Rhodesian Dollar" },
            { "rol", "Romanian Leu (1952\u20132006)" },
            { "ron", "Romanian Leu" },
            { "rsd", "Serbian Dinar" },
            { "rub", "Russian Ruble" },
            { "rur", "Russian Ruble (1991\u20131998)" },
            { "rwf", "Rwandan Franc" },
            { "sar", "Saudi Riyal" },
            { "sbd", "Solomon Islands Dollar" },
            { "scr", "Seychellois Rupee" },
            { "sdd", "Sudanese Dinar (1992\u20132007)" },
            { "sdg", "Sudanese Pound" },
            { "sdp", "Sudanese Pound (1957\u20131998)" },
            { "sek", "Swedish Krona" },
            { "sgd", "Singapore Dollar" },
            { "shp", "St. Helena Pound" },
            { "sit", "Slovenian Tolar" },
            { "skk", "Slovak Koruna" },
            { "sle", "Sierra Leonean New Leone" },
            { "sll", "Sierra Leonean Leone" },
            { "sos", "Somali Shilling" },
            { "srd", "Surinamese Dollar" },
            { "srg", "Surinamese Guilder" },
            { "ssp", "South Sudanese Pound" },
            { "std", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra" },
            { "sur", "Soviet Rouble" },
            { "svc", "Salvadoran Col\u00f3n" },
            { "syp", "Syrian Pound" },
            { "szl", "Swazi Lilangeni" },
            { "thb", "Thai Baht" },
            { "tjr", "Tajikistani Ruble" },
            { "tjs", "Tajikistani Somoni" },
            { "tmm", "Turkmenistani Manat (1993\u20132009)" },
            { "tmt", "Turkmenistani Manat" },
            { "tnd", "Tunisian Dinar" },
            { "top", "Tongan Pa\u02bbanga" },
            { "tpe", "Timorese Escudo" },
            { "trl", "Turkish Lira (1922\u20132005)" },
            { "try", "Turkish Lira" },
            { "ttd", "Trinidad & Tobago Dollar" },
            { "twd", "New Taiwan Dollar" },
            { "tzs", "Tanzanian Shilling" },
            { "uah", "Ukrainian Hryvnia" },
            { "uak", "Ukrainian Karbovanets" },
            { "ugs", "Ugandan Shilling (1966\u20131987)" },
            { "ugx", "Ugandan Shilling" },
            { "usd", "US Dollar" },
            { "usn", "US Dollar (Next day)" },
            { "uss", "US Dollar (Same day)" },
            { "uyi", "Uruguayan Peso (Indexed Units)" },
            { "uyp", "Uruguayan Peso (1975\u20131993)" },
            { "uyu", "Uruguayan Peso" },
            { "uyw", "Uruguayan Nominal Wage Index Unit" },
            { "uzs", "Uzbekistani Som" },
            { "veb", "Venezuelan Bol\u00edvar (1871\u20132008)" },
            { "ved", "Bol\u00edvar Soberano" },
            { "vef", "Venezuelan Bol\u00edvar (2008\u20132018)" },
            { "ves", "Venezuelan Bol\u00edvar" },
            { "vnd", "Vietnamese Dong" },
            { "vnn", "Vietnamese Dong (1978\u20131985)" },
            { "vuv", "Vanuatu Vatu" },
            { "wst", "Samoan Tala" },
            { "xaf", "Central African CFA Franc" },
            { "xag", "Silver" },
            { "xau", "Gold" },
            { "xba", "European Composite Unit" },
            { "xbb", "European Monetary Unit" },
            { "xbc", "European Unit of Account (XBC)" },
            { "xbd", "European Unit of Account (XBD)" },
            { "xcd", "East Caribbean Dollar" },
            { "xdr", "Special Drawing Rights" },
            { "xeu", "European Currency Unit" },
            { "xfo", "French Gold Franc" },
            { "xfu", "French UIC-Franc" },
            { "xof", "West African CFA Franc" },
            { "xpd", "Palladium" },
            { "xpf", "CFP Franc" },
            { "xpt", "Platinum" },
            { "xre", "RINET Funds" },
            { "xsu", "Sucre" },
            { "xts", "Testing Currency Code" },
            { "xua", "ADB Unit of Account" },
            { "xxx", "Unknown Currency" },
            { "ydd", "Yemeni Dinar" },
            { "yer", "Yemeni Rial" },
            { "yud", "Yugoslavian Hard Dinar (1966\u20131990)" },
            { "yum", "Yugoslavian New Dinar (1994\u20132002)" },
            { "yun", "Yugoslavian Convertible Dinar (1990\u20131992)" },
            { "yur", "Yugoslavian Reformed Dinar (1992\u20131993)" },
            { "zal", "South African Rand (financial)" },
            { "zar", "South African Rand" },
            { "zmk", "Zambian Kwacha (1968\u20132012)" },
            { "zmw", "Zambian Kwacha" },
            { "zrn", "Zairean New Zaire (1993\u20131998)" },
            { "zrz", "Zairean Zaire (1971\u20131993)" },
            { "zwd", "Zimbabwean Dollar (1980\u20132008)" },
            { "zwl", "Zimbabwean Dollar (2009)" },
            { "zwr", "Zimbabwean Dollar (2008)" },
        };
        return data;
    }
}
